@@ -1,28 +1,25 @@
 package Net::LCDproc::Widget;
-{
-    $Net::LCDproc::Widget::VERSION = '0.1.1';
-}
-
+$Net::LCDproc::Widget::VERSION = '0.1.2';
 #ABSTRACT: Base class for all the widgets
 
-use v5.10;
-use Moose;
-use Net::LCDproc::Meta::Widget;
+use v5.10.2;
+use Moo;
 use Log::Any qw($log);
-use namespace::autoclean;
+use Types::Standard qw/ArrayRef Bool InstanceOf Str/;
+use namespace::sweep;
 
 has id => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has type => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     traits  => ['NoState'],
     default => sub {
-        my $pkg = shift->meta->{package};
+        my $pkg = ref $_[0];
         my @parts = split /::/, $pkg;
         return lc $parts[-1];
     },
@@ -30,59 +27,37 @@ has type => (
 
 has frame_id => (
     is        => 'rw',
-    isa       => 'Str',
-    traits    => ['NoState'],
+    isa       => Str,
     predicate => 'has_frame_id',
 
     #isa => 'Net::LCDproc::Widget::Frame',
 );
 
 has screen => (
-    is     => 'rw',
-    isa    => 'Net::LCDproc::Screen',
-    traits => ['NoState'],
+    is  => 'rw',
+    isa => InstanceOf ['Net::LCDproc::Screen'],
 );
 
 has is_new => (
-    traits   => [qw/Bool NoState/],
-    is       => 'ro',
-    isa      => 'Bool',
-    default  => 1,
-    required => 1,
-    handles  => {added => 'unset',},
+    is      => 'rw',
+    isa     => Bool,
+    default => 1,
 );
 
 has changed => (
-    traits  => [qw/Bool NoState/],
-    is      => 'rw',
-    isa     => 'Bool',
-    handles => {
-        has_changed    => 'set',
-        change_updated => 'unset',
-    },
+    is  => 'rw',
+    isa => Bool,
 );
 
 has _set_cmd => (
     is       => 'rw',
-    isa      => 'ArrayRef',
-    traits   => ['NoState'],
+    isa      => ArrayRef,
     required => 1,
     default  => sub { [] },
 );
 
 ### Public Methods
 
-sub set {
-    my ($self, $attr_name, $new_val) = @_;
-
-    $log->debugf('Setting %s: "%s"', $attr_name, $new_val) if $log->is_debug;
-    my $attr = $self->meta->get_attribute($attr_name);
-    $attr->set_value($self, $new_val);
-    $self->is_changed;
-
-    return 1;
-}
-
 sub update {
     my $self = shift;
 
@@ -100,7 +75,7 @@ sub update {
 
     $self->screen->_lcdproc->_send_cmd($cmd_str);
 
-    $self->change_updated;
+    $self->changed(0);
     return 1;
 }
 
@@ -120,16 +95,8 @@ sub _get_set_cmd_str {
 
     my $cmd_str = sprintf 'widget_set %s %s', $self->screen->id, $self->id;
 
-    foreach my $name (@{$self->_set_cmd}) {
-        my $attr = $self->meta->get_attribute($name);
-        my $val  = $attr->get_value($self);
-
-        # should only ever be Str or Int
-        if ($attr->type_constraint eq 'Str') {
-            $cmd_str .= " \"$val\"";
-        } else {
-            $cmd_str .= " $val";
-        }
+    foreach my $attr (@{$self->_set_cmd}) {
+        $cmd_str .= sprintf ' "%s"', $self->$attr;
     }
 
     return $cmd_str;
@@ -147,46 +114,44 @@ sub _create_widget_on_server {
     }
     $self->screen->_lcdproc->_send_cmd($add_str);
 
-    $self->added;
+    $self->is_new(0);
 
     # make sure it gets set
-    $self->has_changed;
+    $self->changed(1);
     return 1;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Ioan Rogers
+
 =head1 NAME
 
 Net::LCDproc::Widget - Base class for all the widgets
 
 =head1 VERSION
 
-version 0.1.1
-
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Net::LCDproc|Net::LCDproc>
-
-=back
+version 0.1.2
 
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
 web interface at L<https://github.com/ioanrogers/Net-LCDproc/issues>.
 
+=head1 AVAILABILITY
+
+The project homepage is L<http://metacpan.org/release/Net-LCDproc/>.
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<https://metacpan.org/module/Net::LCDproc/>.
+
 =head1 SOURCE
 
 The development version is on github at L<http://github.com/ioanrogers/Net-LCDproc>
@@ -198,10 +163,33 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Ioan Rogers.
+This software is Copyright (c) 2014 by Ioan Rogers.
 
 This is free software, licensed under:
 
   The GNU General Public License, Version 3, June 2007
 
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
 =cut
